@@ -979,9 +979,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
