@@ -1157,9 +1157,6 @@ class FunctionServiceClient(metaclass=FunctionServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
